@@ -93,6 +93,15 @@ PRODUCTS = {
          "Continuous_Power_Base"),
     "after_market":
         ("After_Market_Quarter_Hour_Power_NL",
-         "After_Market_Quarter_Hour_Power_BE")}
+         "After_Market_Quarter_Hour_Power_BE"),
+    "GB_block_contracts":
+        ("GB_2_Hour_Power",
+         "GB_4_Hour_Power",
+         "GB_3_Plus_4",
+         "GB_Extended_Peak",
+         "GB_Baseload",
+         "GB_Overnight",
+         "GB_Peakload")}
 
-PRODUCTS["all"] = PRODUCTS["hourly"] + PRODUCTS["quarter-hourly"] + PRODUCTS["half-hourly"] + PRODUCTS["continuous"] + PRODUCTS["after_market"]
+PRODUCTS["all"] = (PRODUCTS["hourly"] + PRODUCTS["quarter-hourly"] + PRODUCTS["half-hourly"] + PRODUCTS["continuous"] + PRODUCTS["after_market"]
+                   + PRODUCTS["GB_block_contracts"])
